# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'DeploymentExpense',
    'DeploymentLastRequest',
    'DeploymentProject',
    'DeploymentResource',
    'DeploymentResourceExpense',
    'GetDeploymentExpenseResult',
    'GetDeploymentLastRequestResult',
    'GetDeploymentProjectResult',
    'GetDeploymentResourceResult',
    'GetDeploymentResourceExpenseResult',
]

@pulumi.output_type
class DeploymentExpense(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "additionalExpense":
            suggest = "additional_expense"
        elif key == "computeExpense":
            suggest = "compute_expense"
        elif key == "lastUpdateTime":
            suggest = "last_update_time"
        elif key == "networkExpense":
            suggest = "network_expense"
        elif key == "storageExpense":
            suggest = "storage_expense"
        elif key == "totalExpense":
            suggest = "total_expense"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentExpense. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentExpense.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentExpense.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 additional_expense: Optional[float] = None,
                 code: Optional[str] = None,
                 compute_expense: Optional[float] = None,
                 last_update_time: Optional[str] = None,
                 message: Optional[str] = None,
                 network_expense: Optional[float] = None,
                 storage_expense: Optional[float] = None,
                 total_expense: Optional[float] = None,
                 unit: Optional[str] = None):
        """
        :param float additional_expense: Additional expense incurred for the resource.
        :param str code: Expense sync message code if any.
        :param float compute_expense: Compute expense of the entity.
        :param str last_update_time: Last expense sync time.
        :param str message: Expense sync message if any.
        :param float network_expense: Network expense of the entity.
        :param float storage_expense: Storage expense of the entity.
        :param float total_expense: Total expense of the entity.
        :param str unit: Monetary unit.
        """
        if additional_expense is not None:
            pulumi.set(__self__, "additional_expense", additional_expense)
        if code is not None:
            pulumi.set(__self__, "code", code)
        if compute_expense is not None:
            pulumi.set(__self__, "compute_expense", compute_expense)
        if last_update_time is not None:
            pulumi.set(__self__, "last_update_time", last_update_time)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if network_expense is not None:
            pulumi.set(__self__, "network_expense", network_expense)
        if storage_expense is not None:
            pulumi.set(__self__, "storage_expense", storage_expense)
        if total_expense is not None:
            pulumi.set(__self__, "total_expense", total_expense)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> Optional[float]:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @property
    @pulumi.getter
    def code(self) -> Optional[str]:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> Optional[float]:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> Optional[str]:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @property
    @pulumi.getter
    def message(self) -> Optional[str]:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> Optional[float]:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> Optional[float]:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> Optional[float]:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @property
    @pulumi.getter
    def unit(self) -> Optional[str]:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")


@pulumi.output_type
class DeploymentLastRequest(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "actionId":
            suggest = "action_id"
        elif key == "approvedAt":
            suggest = "approved_at"
        elif key == "blueprintId":
            suggest = "blueprint_id"
        elif key == "catalogItemId":
            suggest = "catalog_item_id"
        elif key == "completedAt":
            suggest = "completed_at"
        elif key == "completedTasks":
            suggest = "completed_tasks"
        elif key == "createdAt":
            suggest = "created_at"
        elif key == "initializedAt":
            suggest = "initialized_at"
        elif key == "requestedBy":
            suggest = "requested_by"
        elif key == "resourceIds":
            suggest = "resource_ids"
        elif key == "totalTasks":
            suggest = "total_tasks"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentLastRequest. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentLastRequest.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentLastRequest.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 action_id: Optional[str] = None,
                 approved_at: Optional[str] = None,
                 blueprint_id: Optional[str] = None,
                 cancelable: Optional[bool] = None,
                 catalog_item_id: Optional[str] = None,
                 completed_at: Optional[str] = None,
                 completed_tasks: Optional[int] = None,
                 created_at: Optional[str] = None,
                 details: Optional[str] = None,
                 dismissed: Optional[bool] = None,
                 id: Optional[str] = None,
                 initialized_at: Optional[str] = None,
                 inputs: Optional[Mapping[str, str]] = None,
                 name: Optional[str] = None,
                 outputs: Optional[Mapping[str, str]] = None,
                 requested_by: Optional[str] = None,
                 resource_ids: Optional[Sequence[str]] = None,
                 status: Optional[str] = None,
                 total_tasks: Optional[int] = None,
                 updated_at: Optional[str] = None):
        """
        :param str action_id: Identifier of the requested action.
        :param str approved_at: Time at which the request was approved.
        :param str blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param bool cancelable: Indicates whether request can be canceled or not.
        :param str catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param str completed_at: Time at which the request completed.
        :param int completed_tasks: The number of tasks completed while fulfilling this request.
        :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param str details: Longer user-friendly details of the request.
        :param bool dismissed: Indicates whether request is in dismissed state.
        :param str id: Unique identifier of the resource.
        :param str initialized_at: Time at which the request was initialized.
        :param Mapping[str, str] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param Mapping[str, str] outputs: Request outputs.
        :param str requested_by: The user that initiated the request.
        :param str status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        :param str updated_at: Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        if action_id is not None:
            pulumi.set(__self__, "action_id", action_id)
        if approved_at is not None:
            pulumi.set(__self__, "approved_at", approved_at)
        if blueprint_id is not None:
            pulumi.set(__self__, "blueprint_id", blueprint_id)
        if cancelable is not None:
            pulumi.set(__self__, "cancelable", cancelable)
        if catalog_item_id is not None:
            pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if completed_at is not None:
            pulumi.set(__self__, "completed_at", completed_at)
        if completed_tasks is not None:
            pulumi.set(__self__, "completed_tasks", completed_tasks)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if dismissed is not None:
            pulumi.set(__self__, "dismissed", dismissed)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if initialized_at is not None:
            pulumi.set(__self__, "initialized_at", initialized_at)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if outputs is not None:
            pulumi.set(__self__, "outputs", outputs)
        if requested_by is not None:
            pulumi.set(__self__, "requested_by", requested_by)
        if resource_ids is not None:
            pulumi.set(__self__, "resource_ids", resource_ids)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if total_tasks is not None:
            pulumi.set(__self__, "total_tasks", total_tasks)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> Optional[str]:
        """
        Identifier of the requested action.
        """
        return pulumi.get(self, "action_id")

    @property
    @pulumi.getter(name="approvedAt")
    def approved_at(self) -> Optional[str]:
        """
        Time at which the request was approved.
        """
        return pulumi.get(self, "approved_at")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> Optional[str]:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter
    def cancelable(self) -> Optional[bool]:
        """
        Indicates whether request can be canceled or not.
        """
        return pulumi.get(self, "cancelable")

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> Optional[str]:
        """
        The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        """
        return pulumi.get(self, "catalog_item_id")

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> Optional[str]:
        """
        Time at which the request completed.
        """
        return pulumi.get(self, "completed_at")

    @property
    @pulumi.getter(name="completedTasks")
    def completed_tasks(self) -> Optional[int]:
        """
        The number of tasks completed while fulfilling this request.
        """
        return pulumi.get(self, "completed_tasks")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def details(self) -> Optional[str]:
        """
        Longer user-friendly details of the request.
        """
        return pulumi.get(self, "details")

    @property
    @pulumi.getter
    def dismissed(self) -> Optional[bool]:
        """
        Indicates whether request is in dismissed state.
        """
        return pulumi.get(self, "dismissed")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initializedAt")
    def initialized_at(self) -> Optional[str]:
        """
        Time at which the request was initialized.
        """
        return pulumi.get(self, "initialized_at")

    @property
    @pulumi.getter
    def inputs(self) -> Optional[Mapping[str, str]]:
        """
        Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        """
        return pulumi.get(self, "inputs")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def outputs(self) -> Optional[Mapping[str, str]]:
        """
        Request outputs.
        """
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter(name="requestedBy")
    def requested_by(self) -> Optional[str]:
        """
        The user that initiated the request.
        """
        return pulumi.get(self, "requested_by")

    @property
    @pulumi.getter(name="resourceIds")
    def resource_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "resource_ids")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalTasks")
    def total_tasks(self) -> Optional[int]:
        return pulumi.get(self, "total_tasks")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[str]:
        """
        Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class DeploymentProject(dict):
    def __init__(__self__, *,
                 description: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 version: Optional[str] = None):
        """
        :param str description: A human-friendly description.
        :param str id: Unique identifier of the resource.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param str version: Version of the entity, if applicable.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        """
        Version of the entity, if applicable.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class DeploymentResource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createdAt":
            suggest = "created_at"
        elif key == "dependsOns":
            suggest = "depends_ons"
        elif key == "propertiesJson":
            suggest = "properties_json"
        elif key == "syncStatus":
            suggest = "sync_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentResource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentResource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentResource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 name: str,
                 created_at: Optional[str] = None,
                 depends_ons: Optional[Sequence[str]] = None,
                 description: Optional[str] = None,
                 expenses: Optional[Sequence['outputs.DeploymentResourceExpense']] = None,
                 properties_json: Optional[str] = None,
                 state: Optional[str] = None,
                 sync_status: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str id: Unique identifier of the resource.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param Sequence[str] depends_ons: A list of other resources this resource depends on.
        :param str description: A human-friendly description.
        :param Sequence['DeploymentResourceExpenseArgs'] expenses: Expense incurred for the deployment.
        :param str properties_json: List of properties in the encoded JSON string format.
        :param str state: The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        :param str sync_status: The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        :param str type: Type of the resource.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if depends_ons is not None:
            pulumi.set(__self__, "depends_ons", depends_ons)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expenses is not None:
            pulumi.set(__self__, "expenses", expenses)
        if properties_json is not None:
            pulumi.set(__self__, "properties_json", properties_json)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if sync_status is not None:
            pulumi.set(__self__, "sync_status", sync_status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dependsOns")
    def depends_ons(self) -> Optional[Sequence[str]]:
        """
        A list of other resources this resource depends on.
        """
        return pulumi.get(self, "depends_ons")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def expenses(self) -> Optional[Sequence['outputs.DeploymentResourceExpense']]:
        """
        Expense incurred for the deployment.
        """
        return pulumi.get(self, "expenses")

    @property
    @pulumi.getter(name="propertiesJson")
    def properties_json(self) -> Optional[str]:
        """
        List of properties in the encoded JSON string format.
        """
        return pulumi.get(self, "properties_json")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="syncStatus")
    def sync_status(self) -> Optional[str]:
        """
        The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        """
        return pulumi.get(self, "sync_status")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Type of the resource.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class DeploymentResourceExpense(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "additionalExpense":
            suggest = "additional_expense"
        elif key == "computeExpense":
            suggest = "compute_expense"
        elif key == "lastUpdateTime":
            suggest = "last_update_time"
        elif key == "networkExpense":
            suggest = "network_expense"
        elif key == "storageExpense":
            suggest = "storage_expense"
        elif key == "totalExpense":
            suggest = "total_expense"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentResourceExpense. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentResourceExpense.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentResourceExpense.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 additional_expense: Optional[float] = None,
                 code: Optional[str] = None,
                 compute_expense: Optional[float] = None,
                 last_update_time: Optional[str] = None,
                 message: Optional[str] = None,
                 network_expense: Optional[float] = None,
                 storage_expense: Optional[float] = None,
                 total_expense: Optional[float] = None,
                 unit: Optional[str] = None):
        """
        :param float additional_expense: Additional expense incurred for the resource.
        :param str code: Expense sync message code if any.
        :param float compute_expense: Compute expense of the entity.
        :param str last_update_time: Last expense sync time.
        :param str message: Expense sync message if any.
        :param float network_expense: Network expense of the entity.
        :param float storage_expense: Storage expense of the entity.
        :param float total_expense: Total expense of the entity.
        :param str unit: Monetary unit.
        """
        if additional_expense is not None:
            pulumi.set(__self__, "additional_expense", additional_expense)
        if code is not None:
            pulumi.set(__self__, "code", code)
        if compute_expense is not None:
            pulumi.set(__self__, "compute_expense", compute_expense)
        if last_update_time is not None:
            pulumi.set(__self__, "last_update_time", last_update_time)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if network_expense is not None:
            pulumi.set(__self__, "network_expense", network_expense)
        if storage_expense is not None:
            pulumi.set(__self__, "storage_expense", storage_expense)
        if total_expense is not None:
            pulumi.set(__self__, "total_expense", total_expense)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> Optional[float]:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @property
    @pulumi.getter
    def code(self) -> Optional[str]:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> Optional[float]:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> Optional[str]:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @property
    @pulumi.getter
    def message(self) -> Optional[str]:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> Optional[float]:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> Optional[float]:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> Optional[float]:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @property
    @pulumi.getter
    def unit(self) -> Optional[str]:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")


@pulumi.output_type
class GetDeploymentExpenseResult(dict):
    def __init__(__self__, *,
                 additional_expense: float,
                 code: str,
                 compute_expense: float,
                 last_update_time: str,
                 message: str,
                 network_expense: float,
                 storage_expense: float,
                 total_expense: float,
                 unit: str):
        """
        :param float additional_expense: Additional expense incurred for the resource.
        :param str code: Expense sync message code if any.
        :param float compute_expense: Compute expense of the entity.
        :param str last_update_time: Last expense sync time.
        :param str message: Expense sync message if any.
        :param float network_expense: Network expense of the entity.
        :param float storage_expense: Storage expense of the entity.
        :param float total_expense: Total expense of the entity.
        :param str unit: Monetary unit.
        """
        pulumi.set(__self__, "additional_expense", additional_expense)
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "compute_expense", compute_expense)
        pulumi.set(__self__, "last_update_time", last_update_time)
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "network_expense", network_expense)
        pulumi.set(__self__, "storage_expense", storage_expense)
        pulumi.set(__self__, "total_expense", total_expense)
        pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> float:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> float:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> str:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @property
    @pulumi.getter
    def message(self) -> str:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> float:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> float:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> float:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @property
    @pulumi.getter
    def unit(self) -> str:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")


@pulumi.output_type
class GetDeploymentLastRequestResult(dict):
    def __init__(__self__, *,
                 action_id: str,
                 approved_at: str,
                 blueprint_id: str,
                 cancelable: bool,
                 catalog_item_id: str,
                 completed_at: str,
                 completed_tasks: int,
                 created_at: str,
                 details: str,
                 dismissed: bool,
                 id: str,
                 initialized_at: str,
                 inputs: Mapping[str, str],
                 name: str,
                 outputs: Mapping[str, str],
                 requested_by: str,
                 resource_ids: Sequence[str],
                 status: str,
                 total_tasks: int,
                 updated_at: str):
        """
        :param str action_id: Identifier of the requested action.
        :param str approved_at: Time at which the request was approved.
        :param str blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param bool cancelable: Indicates whether request can be canceled or not.
        :param str catalog_item_id: Identifier of the requested catalog item in the form ‘UUID:version’.
        :param str completed_at: Time at which the request completed.
        :param int completed_tasks: The number of tasks completed while fulfilling this request.
        :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param str details: Longer user-friendly details of the request.
        :param bool dismissed: Indicates whether request is in dismissed state.
        :param str id: The id of the deployment. One of `id` or `name` must be provided.
        :param str initialized_at: Time at which the request was initialized.
        :param Mapping[str, str] inputs: List of request inputs.
        :param str name: Name of the deployment. One of `id` or `name` must be provided.
        :param Mapping[str, str] outputs: Request outputs.
        :param str requested_by: The user that initiated the request.
        :param str status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        :param str updated_at: Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        pulumi.set(__self__, "action_id", action_id)
        pulumi.set(__self__, "approved_at", approved_at)
        pulumi.set(__self__, "blueprint_id", blueprint_id)
        pulumi.set(__self__, "cancelable", cancelable)
        pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        pulumi.set(__self__, "completed_at", completed_at)
        pulumi.set(__self__, "completed_tasks", completed_tasks)
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "details", details)
        pulumi.set(__self__, "dismissed", dismissed)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "initialized_at", initialized_at)
        pulumi.set(__self__, "inputs", inputs)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "outputs", outputs)
        pulumi.set(__self__, "requested_by", requested_by)
        pulumi.set(__self__, "resource_ids", resource_ids)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "total_tasks", total_tasks)
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> str:
        """
        Identifier of the requested action.
        """
        return pulumi.get(self, "action_id")

    @property
    @pulumi.getter(name="approvedAt")
    def approved_at(self) -> str:
        """
        Time at which the request was approved.
        """
        return pulumi.get(self, "approved_at")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> str:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter
    def cancelable(self) -> bool:
        """
        Indicates whether request can be canceled or not.
        """
        return pulumi.get(self, "cancelable")

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> str:
        """
        Identifier of the requested catalog item in the form ‘UUID:version’.
        """
        return pulumi.get(self, "catalog_item_id")

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> str:
        """
        Time at which the request completed.
        """
        return pulumi.get(self, "completed_at")

    @property
    @pulumi.getter(name="completedTasks")
    def completed_tasks(self) -> int:
        """
        The number of tasks completed while fulfilling this request.
        """
        return pulumi.get(self, "completed_tasks")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def details(self) -> str:
        """
        Longer user-friendly details of the request.
        """
        return pulumi.get(self, "details")

    @property
    @pulumi.getter
    def dismissed(self) -> bool:
        """
        Indicates whether request is in dismissed state.
        """
        return pulumi.get(self, "dismissed")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initializedAt")
    def initialized_at(self) -> str:
        """
        Time at which the request was initialized.
        """
        return pulumi.get(self, "initialized_at")

    @property
    @pulumi.getter
    def inputs(self) -> Mapping[str, str]:
        """
        List of request inputs.
        """
        return pulumi.get(self, "inputs")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def outputs(self) -> Mapping[str, str]:
        """
        Request outputs.
        """
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter(name="requestedBy")
    def requested_by(self) -> str:
        """
        The user that initiated the request.
        """
        return pulumi.get(self, "requested_by")

    @property
    @pulumi.getter(name="resourceIds")
    def resource_ids(self) -> Sequence[str]:
        return pulumi.get(self, "resource_ids")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalTasks")
    def total_tasks(self) -> int:
        return pulumi.get(self, "total_tasks")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class GetDeploymentProjectResult(dict):
    def __init__(__self__, *,
                 description: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 version: Optional[str] = None):
        """
        :param str description: A description of the resource.
        :param str id: The id of the deployment. One of `id` or `name` must be provided.
        :param str name: Name of the deployment. One of `id` or `name` must be provided.
        :param str version: Version of the entity, if applicable.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A description of the resource.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The id of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        """
        Version of the entity, if applicable.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetDeploymentResourceResult(dict):
    def __init__(__self__, *,
                 expenses: Sequence['outputs.GetDeploymentResourceExpenseResult'],
                 id: str,
                 name: str,
                 created_at: Optional[str] = None,
                 depends_ons: Optional[Sequence[str]] = None,
                 description: Optional[str] = None,
                 properties_json: Optional[str] = None,
                 state: Optional[str] = None,
                 sync_status: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param Sequence['GetDeploymentResourceExpenseArgs'] expenses: Expense incurred for this resource.
        :param str id: The id of the deployment. One of `id` or `name` must be provided.
        :param str name: Name of the deployment. One of `id` or `name` must be provided.
        :param str created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param Sequence[str] depends_ons: A list of other resources this resource depends on.
        :param str description: A description of the resource.
        :param str properties_json: List of properties in the encoded JSON string format.
        :param str state: The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        :param str sync_status: The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        :param str type: Type of the resource.
        """
        pulumi.set(__self__, "expenses", expenses)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if depends_ons is not None:
            pulumi.set(__self__, "depends_ons", depends_ons)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if properties_json is not None:
            pulumi.set(__self__, "properties_json", properties_json)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if sync_status is not None:
            pulumi.set(__self__, "sync_status", sync_status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def expenses(self) -> Sequence['outputs.GetDeploymentResourceExpenseResult']:
        """
        Expense incurred for this resource.
        """
        return pulumi.get(self, "expenses")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the deployment. One of `id` or `name` must be provided.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dependsOns")
    def depends_ons(self) -> Optional[Sequence[str]]:
        """
        A list of other resources this resource depends on.
        """
        return pulumi.get(self, "depends_ons")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A description of the resource.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="propertiesJson")
    def properties_json(self) -> Optional[str]:
        """
        List of properties in the encoded JSON string format.
        """
        return pulumi.get(self, "properties_json")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="syncStatus")
    def sync_status(self) -> Optional[str]:
        """
        The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        """
        return pulumi.get(self, "sync_status")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Type of the resource.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetDeploymentResourceExpenseResult(dict):
    def __init__(__self__, *,
                 additional_expense: float,
                 code: str,
                 compute_expense: float,
                 last_update_time: str,
                 message: str,
                 network_expense: float,
                 storage_expense: float,
                 total_expense: float,
                 unit: str):
        """
        :param float additional_expense: Additional expense incurred for the resource.
        :param str code: Expense sync message code if any.
        :param float compute_expense: Compute expense of the entity.
        :param str last_update_time: Last expense sync time.
        :param str message: Expense sync message if any.
        :param float network_expense: Network expense of the entity.
        :param float storage_expense: Storage expense of the entity.
        :param float total_expense: Total expense of the entity.
        :param str unit: Monetary unit.
        """
        pulumi.set(__self__, "additional_expense", additional_expense)
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "compute_expense", compute_expense)
        pulumi.set(__self__, "last_update_time", last_update_time)
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "network_expense", network_expense)
        pulumi.set(__self__, "storage_expense", storage_expense)
        pulumi.set(__self__, "total_expense", total_expense)
        pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> float:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> float:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> str:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @property
    @pulumi.getter
    def message(self) -> str:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> float:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> float:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> float:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @property
    @pulumi.getter
    def unit(self) -> str:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSecurityGroupLinkResult',
    'GetSecurityGroupRuleResult',
]

@pulumi.output_type
class GetSecurityGroupLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetSecurityGroupRuleResult(dict):
    def __init__(__self__, *,
                 access: str,
                 direction: str,
                 ip_range_cidr: int,
                 ports: str,
                 protocol: str,
                 name: Optional[str] = None,
                 service: Optional[str] = None):
        """
        :param str name: Name of the security group.
        """
        pulumi.set(__self__, "access", access)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "ip_range_cidr", ip_range_cidr)
        pulumi.set(__self__, "ports", ports)
        pulumi.set(__self__, "protocol", protocol)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service is not None:
            pulumi.set(__self__, "service", service)

    @property
    @pulumi.getter
    def access(self) -> str:
        return pulumi.get(self, "access")

    @property
    @pulumi.getter
    def direction(self) -> str:
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter(name="ipRangeCidr")
    def ip_range_cidr(self) -> int:
        return pulumi.get(self, "ip_range_cidr")

    @property
    @pulumi.getter
    def ports(self) -> str:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the security group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def service(self) -> Optional[str]:
        return pulumi.get(self, "service")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ItemEntitlementDefinition',
    'SourceEntitlementDefinition',
    'GetItemEntitlementDefinitionResult',
    'GetItemProjectResult',
    'GetItemTypeResult',
    'GetItemVersionResult',
    'GetSourceEntitlementDefinitionResult',
]

@pulumi.output_type
class ItemEntitlementDefinition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "iconId":
            suggest = "icon_id"
        elif key == "numberOfItems":
            suggest = "number_of_items"
        elif key == "sourceName":
            suggest = "source_name"
        elif key == "sourceType":
            suggest = "source_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ItemEntitlementDefinition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ItemEntitlementDefinition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ItemEntitlementDefinition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[str] = None,
                 icon_id: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 number_of_items: Optional[int] = None,
                 source_name: Optional[str] = None,
                 source_type: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str description: Description of the catalog item.
        :param str icon_id: Icon id of associated catalog item.
        :param str id: Id of the catalog item.
        :param str name: Name of the catalog item.
        :param int number_of_items: Number of items in the associated catalog source.
        :param str source_name: Catalog source name.
        :param str source_type: Catalog source type.
        :param str type: Content definition type.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if icon_id is not None:
            pulumi.set(__self__, "icon_id", icon_id)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_items is not None:
            pulumi.set(__self__, "number_of_items", number_of_items)
        if source_name is not None:
            pulumi.set(__self__, "source_name", source_name)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Description of the catalog item.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> Optional[str]:
        """
        Icon id of associated catalog item.
        """
        return pulumi.get(self, "icon_id")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Id of the catalog item.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the catalog item.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> Optional[int]:
        """
        Number of items in the associated catalog source.
        """
        return pulumi.get(self, "number_of_items")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> Optional[str]:
        """
        Catalog source name.
        """
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[str]:
        """
        Catalog source type.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Content definition type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class SourceEntitlementDefinition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "iconId":
            suggest = "icon_id"
        elif key == "numberOfItems":
            suggest = "number_of_items"
        elif key == "sourceName":
            suggest = "source_name"
        elif key == "sourceType":
            suggest = "source_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SourceEntitlementDefinition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SourceEntitlementDefinition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SourceEntitlementDefinition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[str] = None,
                 icon_id: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 number_of_items: Optional[int] = None,
                 source_name: Optional[str] = None,
                 source_type: Optional[str] = None,
                 type: Optional[str] = None):
        if description is not None:
            pulumi.set(__self__, "description", description)
        if icon_id is not None:
            pulumi.set(__self__, "icon_id", icon_id)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_items is not None:
            pulumi.set(__self__, "number_of_items", number_of_items)
        if source_name is not None:
            pulumi.set(__self__, "source_name", source_name)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> Optional[str]:
        return pulumi.get(self, "icon_id")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> Optional[int]:
        return pulumi.get(self, "number_of_items")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> Optional[str]:
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[str]:
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetItemEntitlementDefinitionResult(dict):
    def __init__(__self__, *,
                 description: str,
                 icon_id: str,
                 id: str,
                 name: str,
                 number_of_items: int,
                 source_name: str,
                 source_type: str,
                 type: str):
        """
        :param str description: Description of the catalog item.
        :param str icon_id: Icon id of associated catalog item.
        :param str id: The id of entitlement. One of `catalog_item_id` or `id` must be provided.
        :param str name: Name of the catalog item.
        :param int number_of_items: Number of items in the associated catalog source.
        :param str source_name: Catalog source name.
        :param str source_type: Catalog source type.
        :param str type: Content definition type.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "icon_id", icon_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "number_of_items", number_of_items)
        pulumi.set(__self__, "source_name", source_name)
        pulumi.set(__self__, "source_type", source_type)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the catalog item.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> str:
        """
        Icon id of associated catalog item.
        """
        return pulumi.get(self, "icon_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of entitlement. One of `catalog_item_id` or `id` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the catalog item.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> int:
        """
        Number of items in the associated catalog source.
        """
        return pulumi.get(self, "number_of_items")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> str:
        """
        Catalog source name.
        """
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> str:
        """
        Catalog source type.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Content definition type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetItemProjectResult(dict):
    def __init__(__self__, *,
                 description: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 version: Optional[str] = None):
        """
        :param str description: A human-friendly description.
        :param str id: The id of catalog item. One of `id`, or `name` must be provided.
        :param str name: Name of the catalog item. One of `id`, or `name` must be provided.
        :param str version: Version of the entity, if applicable.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The id of catalog item. One of `id`, or `name` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the catalog item. One of `id`, or `name` must be provided.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        """
        Version of the entity, if applicable.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetItemTypeResult(dict):
    def __init__(__self__, *,
                 description: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 version: Optional[str] = None):
        """
        :param str description: A human-friendly description.
        :param str id: The id of catalog item. One of `id`, or `name` must be provided.
        :param str name: Name of the catalog item. One of `id`, or `name` must be provided.
        :param str version: Version of the entity, if applicable.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The id of catalog item. One of `id`, or `name` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the catalog item. One of `id`, or `name` must be provided.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        """
        Version of the entity, if applicable.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetItemVersionResult(dict):
    def __init__(__self__, *,
                 created_at: Optional[str] = None,
                 description: Optional[str] = None,
                 id: Optional[str] = None):
        """
        :param str created_at: Date-time when catalog item version was created at.
        :param str description: A human-friendly description.
        :param str id: The id of catalog item. One of `id`, or `name` must be provided.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        """
        Date-time when catalog item version was created at.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The id of catalog item. One of `id`, or `name` must be provided.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class GetSourceEntitlementDefinitionResult(dict):
    def __init__(__self__, *,
                 description: str,
                 icon_id: str,
                 id: str,
                 name: str,
                 number_of_items: int,
                 source_name: str,
                 source_type: str,
                 type: str):
        """
        :param str description: Description of the catalog source.
        :param str icon_id: Icon id of associated catalog source.
        :param str id: The id of entitlement. One of `catalog_source_id` or `id` must be provided.
        :param str name: Name of the catalog source.
        :param int number_of_items: Number of items in the associated catalog source.
        :param str source_name: Catalog source name.
        :param str source_type: Catalog source type.
        :param str type: Content definition type.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "icon_id", icon_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "number_of_items", number_of_items)
        pulumi.set(__self__, "source_name", source_name)
        pulumi.set(__self__, "source_type", source_type)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the catalog source.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> str:
        """
        Icon id of associated catalog source.
        """
        return pulumi.get(self, "icon_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of entitlement. One of `catalog_source_id` or `id` must be provided.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the catalog source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> int:
        """
        Number of items in the associated catalog source.
        """
        return pulumi.get(self, "number_of_items")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> str:
        """
        Catalog source name.
        """
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> str:
        """
        Catalog source type.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Content definition type.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('vra')


class _ExportableConfig(types.ModuleType):
    @property
    def access_token(self) -> Optional[str]:
        """
        The access token for API operations.
        """
        return __config__.get('accessToken')

    @property
    def insecure(self) -> Optional[bool]:
        """
        Specify whether to validate TLS certificates.
        """
        return __config__.get_bool('insecure')

    @property
    def reauthorize_timeout(self) -> Optional[str]:
        """
        Specify timeout for how often to reauthorize the access token
        """
        return __config__.get('reauthorizeTimeout')

    @property
    def refresh_token(self) -> Optional[str]:
        """
        The refresh token for API operations.
        """
        return __config__.get('refreshToken')

    @property
    def url(self) -> Optional[str]:
        """
        The base url for API operations.
        """
        return __config__.get('url')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'AwsLink',
    'AwsTag',
    'AzureLink',
    'AzureTag',
    'GcpLink',
    'GcpTag',
    'NsxtLink',
    'NsxtTag',
    'NsxvLink',
    'NsxvTag',
    'VSphereLink',
    'VSphereTag',
    'VmcLink',
    'VmcTag',
    'GetAwsLinkResult',
    'GetAwsTagResult',
    'GetAzureLinkResult',
    'GetAzureTagResult',
    'GetGcpLinkResult',
    'GetGcpTagResult',
    'GetNsxtLinkResult',
    'GetNsxtTagResult',
    'GetNsxvLinkResult',
    'GetNsxvTagResult',
    'GetVSphereLinkResult',
    'GetVSphereTagResult',
    'GetVmcLinkResult',
    'GetVmcTagResult',
]

@pulumi.output_type
class AwsLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class AwsTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class AzureLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class AzureTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GcpLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GcpTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class NsxtLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class NsxtTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class NsxvLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class NsxvTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class VSphereLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class VSphereTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class VmcLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class VmcTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAwsLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetAwsTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAzureLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetAzureTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetGcpLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetGcpTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetNsxtLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetNsxtTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetNsxvLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetNsxvTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVSphereLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetVSphereTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVmcLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetVmcTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MachineBootConfig',
    'MachineConstraint',
    'MachineDisk',
    'MachineDisksList',
    'MachineImageDiskConstraint',
    'MachineLink',
    'MachineNic',
    'MachineTag',
    'GetMachineLinkResult',
    'GetMachineTagResult',
]

@pulumi.output_type
class MachineBootConfig(dict):
    def __init__(__self__, *,
                 content: Optional[str] = None):
        """
        :param str content: Calid cloud config data in json-escaped yaml syntax.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)

    @property
    @pulumi.getter
    def content(self) -> Optional[str]:
        """
        Calid cloud config data in json-escaped yaml syntax.
        """
        return pulumi.get(self, "content")


@pulumi.output_type
class MachineConstraint(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        """
        :param str expression: Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        :param bool mandatory: Indicates whether this constraint should be strictly enforced or not.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        """
        Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        """
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        """
        Indicates whether this constraint should be strictly enforced or not.
        """
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class MachineDisk(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "blockDeviceId":
            suggest = "block_device_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MachineDisk. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MachineDisk.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MachineDisk.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 block_device_id: str,
                 description: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str block_device_id: ID of the existing block device.
        :param str description: Human-friendly description.
        :param str name: Human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "block_device_id", block_device_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="blockDeviceId")
    def block_device_id(self) -> str:
        """
        ID of the existing block device.
        """
        return pulumi.get(self, "block_device_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class MachineDisksList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "blockDeviceId":
            suggest = "block_device_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MachineDisksList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MachineDisksList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MachineDisksList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 block_device_id: str,
                 description: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str block_device_id: ID of the existing block device.
        :param str description: Human-friendly description.
        :param str name: Human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "block_device_id", block_device_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="blockDeviceId")
    def block_device_id(self) -> str:
        """
        ID of the existing block device.
        """
        return pulumi.get(self, "block_device_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class MachineImageDiskConstraint(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        """
        :param str expression: Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        :param bool mandatory: Indicates whether this constraint should be strictly enforced or not.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        """
        Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        """
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        """
        Indicates whether this constraint should be strictly enforced or not.
        """
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class MachineLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class MachineNic(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "networkId":
            suggest = "network_id"
        elif key == "customProperties":
            suggest = "custom_properties"
        elif key == "deviceIndex":
            suggest = "device_index"
        elif key == "securityGroupIds":
            suggest = "security_group_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MachineNic. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MachineNic.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MachineNic.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 network_id: str,
                 addresses: Optional[Sequence[str]] = None,
                 custom_properties: Optional[Mapping[str, Any]] = None,
                 description: Optional[str] = None,
                 device_index: Optional[int] = None,
                 name: Optional[str] = None,
                 security_group_ids: Optional[Sequence[str]] = None):
        """
        :param str network_id: ID of the network instance that this network interface plugs into.
        :param Sequence[str] addresses: List of IP addresses allocated or in use by this network interface.
               example:[ "10.1.2.190" ]
        :param Mapping[str, Any] custom_properties: Additional properties that may be used to extend the base type.
        :param str description: Human-friendly description.
        :param int device_index: The device index of this network interface.
        :param str name: Human-friendly name used as an identifier in APIs that support this option.
        :param Sequence[str] security_group_ids: List of security group ids which this network interface will be assigned to.
        """
        pulumi.set(__self__, "network_id", network_id)
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if device_index is not None:
            pulumi.set(__self__, "device_index", device_index)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> str:
        """
        ID of the network instance that this network interface plugs into.
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def addresses(self) -> Optional[Sequence[str]]:
        """
        List of IP addresses allocated or in use by this network interface.
        example:[ "10.1.2.190" ]
        """
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[Mapping[str, Any]]:
        """
        Additional properties that may be used to extend the base type.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="deviceIndex")
    def device_index(self) -> Optional[int]:
        """
        The device index of this network interface.
        """
        return pulumi.get(self, "device_index")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[Sequence[str]]:
        """
        List of security group ids which this network interface will be assigned to.
        """
        return pulumi.get(self, "security_group_ids")


@pulumi.output_type
class MachineTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetMachineLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetMachineTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAzureResult',
    'AwaitableGetAzureResult',
    'get_azure',
    'get_azure_output',
]

@pulumi.output_type
class GetAzureResult:
    """
    A collection of values returned by getAzure.
    """
    def __init__(__self__, application_id=None, created_at=None, description=None, id=None, links=None, name=None, org_id=None, owner=None, regions=None, subscription_id=None, tags=None, tenant_id=None, updated_at=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> str:
        """
        Azure Client Application ID.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetAzureLinkResult']:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of region names that are enabled for this account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        """
        Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetAzureTagResult']:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetAzureResult(GetAzureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureResult(
            application_id=self.application_id,
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            regions=self.regions,
            subscription_id=self.subscription_id,
            tags=self.tags,
            tenant_id=self.tenant_id,
            updated_at=self.updated_at)


def get_azure(id: Optional[str] = None,
              name: Optional[str] = None,
              tags: Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureResult:
    """
    Provides a VMware vRA cloudaccount.Azure data source.

    ## Example Usage
    ### S

    **Azure cloud account data source by its id:**

    This is an example of how to read the cloud account data source using its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(id=var["vra_cloud_account_azure_id"])
    ```

    **Azure cloud account data source by its name:**

    This is an example of how to read the cloud account data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(name=var["vra_cloud_account_azure_name"])
    ```


    :param str id: The id of this Azure cloud account.
    :param str name: The name of this Azure cloud account.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "vmware", "value": "provider" } ]
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:cloudaccount/getAzure:getAzure', __args__, opts=opts, typ=GetAzureResult).value

    return AwaitableGetAzureResult(
        application_id=__ret__.application_id,
        created_at=__ret__.created_at,
        description=__ret__.description,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        regions=__ret__.regions,
        subscription_id=__ret__.subscription_id,
        tags=__ret__.tags,
        tenant_id=__ret__.tenant_id,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_azure)
def get_azure_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                     name: Optional[pulumi.Input[Optional[str]]] = None,
                     tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAzureResult]:
    """
    Provides a VMware vRA cloudaccount.Azure data source.

    ## Example Usage
    ### S

    **Azure cloud account data source by its id:**

    This is an example of how to read the cloud account data source using its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(id=var["vra_cloud_account_azure_id"])
    ```

    **Azure cloud account data source by its name:**

    This is an example of how to read the cloud account data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(name=var["vra_cloud_account_azure_name"])
    ```


    :param str id: The id of this Azure cloud account.
    :param str name: The name of this Azure cloud account.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "vmware", "value": "provider" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ComputeLinkArgs',
    'ComputeTagArgs',
    'DatastoreVSphereLinkArgs',
    'DatastoreVSphereTagArgs',
    'NetworkVSphereLinkArgs',
    'NetworkVSphereTagArgs',
    'GetComputeTagArgs',
    'GetDatastoreVSphereTagArgs',
    'GetNetworkTagArgs',
]

@pulumi.input_type
class ComputeLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class ComputeTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] key: Tag’s key.
        :param pulumi.Input[str] value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class DatastoreVSphereLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class DatastoreVSphereTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] key: Tag’s key.
        :param pulumi.Input[str] value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class NetworkVSphereLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class NetworkVSphereTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetComputeTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetDatastoreVSphereTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetNetworkTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetZoneResult',
    'AwaitableGetZoneResult',
    'get_zone',
    'get_zone_output',
]

@pulumi.output_type
class GetZoneResult:
    """
    A collection of values returned by getZone.
    """
    def __init__(__self__, cloud_account_id=None, compute_ids=None, created_at=None, custom_properties=None, description=None, external_region_id=None, folder=None, id=None, links=None, name=None, org_id=None, owner=None, placement_policy=None, tags=None, tags_to_matches=None, updated_at=None):
        if cloud_account_id and not isinstance(cloud_account_id, str):
            raise TypeError("Expected argument 'cloud_account_id' to be a str")
        pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if compute_ids and not isinstance(compute_ids, list):
            raise TypeError("Expected argument 'compute_ids' to be a list")
        pulumi.set(__self__, "compute_ids", compute_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if folder and not isinstance(folder, str):
            raise TypeError("Expected argument 'folder' to be a str")
        pulumi.set(__self__, "folder", folder)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if placement_policy and not isinstance(placement_policy, str):
            raise TypeError("Expected argument 'placement_policy' to be a str")
        pulumi.set(__self__, "placement_policy", placement_policy)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tags_to_matches and not isinstance(tags_to_matches, list):
            raise TypeError("Expected argument 'tags_to_matches' to be a list")
        pulumi.set(__self__, "tags_to_matches", tags_to_matches)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> str:
        """
        The ID of the cloud account this zone belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="computeIds")
    def compute_ids(self) -> Sequence[str]:
        """
        The ids of the compute resources that has been explicitly assigned to this zone.
        """
        return pulumi.get(self, "compute_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        """
        A list of key value pair of properties that will be used.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region for which this zone is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def folder(self) -> str:
        """
        The folder relative path to the datacenter where resources are deployed to (only applicable for vSphere cloud zones).
        """
        return pulumi.get(self, "folder")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetZoneLinkResult']:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> str:
        """
        The placement policy for the zone. One of `DEFAULT`, `SPREAD` or `BINPACK`.
        """
        return pulumi.get(self, "placement_policy")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetZoneTagResult']:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsToMatches")
    def tags_to_matches(self) -> Sequence['outputs.GetZoneTagsToMatchResult']:
        """
        A set of tag keys and optional values for compute resource filtering:
        """
        return pulumi.get(self, "tags_to_matches")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetZoneResult(GetZoneResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetZoneResult(
            cloud_account_id=self.cloud_account_id,
            compute_ids=self.compute_ids,
            created_at=self.created_at,
            custom_properties=self.custom_properties,
            description=self.description,
            external_region_id=self.external_region_id,
            folder=self.folder,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            placement_policy=self.placement_policy,
            tags=self.tags,
            tags_to_matches=self.tags_to_matches,
            updated_at=self.updated_at)


def get_zone(id: Optional[str] = None,
             name: Optional[str] = None,
             tags: Optional[Sequence[pulumi.InputType['GetZoneTagArgs']]] = None,
             tags_to_matches: Optional[Sequence[pulumi.InputType['GetZoneTagsToMatchArgs']]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetZoneResult:
    """
    ## Example Usage
    ### S

    This is an example of how to read a zone data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    test_zone = vra.zone.get_zone(name=var["zone_name"])
    ```

    A zone data source supports the following arguments:


    :param str id: The id of the zone resource instance.
    :param str name: A human-friendly name used as an identifier for the zone resource instance.
    :param Sequence[pulumi.InputType['GetZoneTagArgs']] tags: A set of tag keys and optional values that were set on this resource:
    :param Sequence[pulumi.InputType['GetZoneTagsToMatchArgs']] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['tags'] = tags
    __args__['tagsToMatches'] = tags_to_matches
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:zone/getZone:getZone', __args__, opts=opts, typ=GetZoneResult).value

    return AwaitableGetZoneResult(
        cloud_account_id=__ret__.cloud_account_id,
        compute_ids=__ret__.compute_ids,
        created_at=__ret__.created_at,
        custom_properties=__ret__.custom_properties,
        description=__ret__.description,
        external_region_id=__ret__.external_region_id,
        folder=__ret__.folder,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        placement_policy=__ret__.placement_policy,
        tags=__ret__.tags,
        tags_to_matches=__ret__.tags_to_matches,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_zone)
def get_zone_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                    name: Optional[pulumi.Input[Optional[str]]] = None,
                    tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetZoneTagArgs']]]]] = None,
                    tags_to_matches: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetZoneTagsToMatchArgs']]]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetZoneResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to read a zone data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    test_zone = vra.zone.get_zone(name=var["zone_name"])
    ```

    A zone data source supports the following arguments:


    :param str id: The id of the zone resource instance.
    :param str name: A human-friendly name used as an identifier for the zone resource instance.
    :param Sequence[pulumi.InputType['GetZoneTagArgs']] tags: A set of tag keys and optional values that were set on this resource:
    :param Sequence[pulumi.InputType['GetZoneTagsToMatchArgs']] tags_to_matches: A set of tag keys and optional values for compute resource filtering:
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'BlueprintValidationMessageArgs',
]

@pulumi.input_type
class BlueprintValidationMessageArgs:
    def __init__(__self__, *,
                 message: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 resource_name: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        if message is not None:
            pulumi.set(__self__, "message", message)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


